#!/bin/sh
# Script to create and tailor for Redhat 6.1 Linux NetworkStation boot from selected rpms
# Last edited: 3/01/00
# Command:
#  rh61_create_bootdir_from_rpm.sh <server-IP - mandatory> <optional boot-dir - default = /nstation/linux> 

set +x

echo "CREATE Redhat 6.1 Linux client Boot Directory - Start"

if [ $1 = "?" ]; then
  echo "Command for NetworkStation server-boot Linux Redhat6.1 client is as follows:"
  echo "rh61_create_bootdir_from_rpm.sh <server-IP address>  <client BOOT-DIR - optional>"
  echo "   default client-boot-directory is /nstation/linux"
  exit
fi

# set the IP address
IP=$1
if [ -z "$IP" ]; then
  echo "ERROR: Must specify server IP address"
  exit
fi

BOOT_DIR=$2
if [ -z "$BOOT_DIR" ]; then
  echo "Linux Client Boot Directory NOT specified."
  echo "   Assumed default BOOT Directory: /nstation/linux"
  BOOT_DIR=/nstation/linux
fi

current_dir=`pwd`

echo "Linux NetworkStation Client boot directory:" BOOT_DIR=$BOOT_DIR
echo current_dir $current_dir
echo Server IP address specified is $IP

# Check if CDROM is mounted and files are present - CHECK if its Redhat 6.1 CD ???
if [ -d /mnt/cdrom/RedHat/RPMS ]; then
  echo ""
else
  echo ""
  echo "ERROR: No RedHat 6.1 CD - please insert the CD now and rerun this script"
  echo ""
  exit
fi

# Future - Ask user if entries are valid

# create the boot dir - do we need to check is boot image has alredy been created
bin/mkdirhier ${BOOT_DIR}
bin/mkdirhier  ${BOOT_DIR}/var/lib/rpm
mkdir  ${BOOT_DIR}/var/tmp

# ============  Install RPMS from a shell script =================
if [ ! -f ./rh61_rpm.list ]; then
   echo "ERROR: No rpm list for Redhat 6.1 distribution - Check the package "
   exit
fi
awk -fAWKS/create_rpm_script_awk -vROOT=$BOOT_DIR -vRPM_DIR="/mnt/cdrom/RedHat/RPMS/"  ./rh61_rpm.list > ./rh61_rpm.sh
chmod a+x ./rh61_rpm.sh 
echo "INSTALL RPMS - ITERATION # 1 (THIS WILL TAKE APPROXIMATELY TIME 10 MINUTES) ... "
./rh61_rpm.sh 

# remove /boot directory
rm -rf $BOOT_DIR/boot

# Move the rpm directory to root. In rc.sysinit, /tmp/var/lib/rpm will be linked to /rpm
mv $BOOT_DIR/var/lib/rpm  $BOOT_DIR/rpm

# Remove /etc/mtab file 
echo "Modify BOOT_DIR/etc/mtab file"
if [ -f $BOOT_DIR/etc/mtab ]; then
rm $BOOT_DIR/etc/mtab
fi
touch $BOOT_DIR/etc/mtab

# ============ Create  /etc/fstab file  ========================
echo "Create " $BOOT_DIR"/etc/fstab file"
if [ -f $BOOT_DIR/etc/fstab.org ]; then
  echo $BOOT_DIR/etc/fstab.org file already exists
else
  if [ -f $BOOT_DIR/etc/fstab ]; then
    mv $BOOT_DIR/etc/fstab $BOOT_DIR/etc/fstab.org
  fi
fi
echo "## Generated for IBM Network Station " > $BOOT_DIR/etc/fstab
echo $IP:$BOOT_DIR " /  nfs  defaults  1 1" >> $BOOT_DIR/etc/fstab
echo "none   /proc  proc     defaults  0 0" >> $BOOT_DIR/etc/fstab
echo "none   /dev/pts   devpts  gid=5,mode=620  0 0" >> $BOOT_DIR/etc/fstab

# ============ Modify /etc/inittab file  ========================
echo Modify $BOOT_DIR/etc/inittab to call rc.sysinit.IBM_NS
if [ -f $BOOT_DIR/etc/inittab.org ]; then
  echo $BOOT_DIR/etc/inittab.org file already exists
else
  mv $BOOT_DIR/etc/inittab $BOOT_DIR/etc/inittab.org
fi
awk -fAWKS/inittab_awk -vREPLACE="rc.sysinit" -vBY="rc.sysinit.IBM_NS.sboot"  $BOOT_DIR/etc/inittab.org > $BOOT_DIR/etc/inittab

# For GUI-login - currently commented out, until we have menu options for GUI-login
#cp $BOOT_DIR/etc/inittab  $BOOT_DIR/etc/inittab.tmp
#awk -fAWKS/inittab_awk  -vREPLACE="id:3:initdefault:" -vBY="id:5:initdefault:"  $BOOT_DIR/etc/inittab.tmp > $BOOT_DIR/etc/inittab

# ============ Rename unneeded services  ========================
echo "Rename unneeded services during client boot"
if [ -f $BOOT_DIR/etc/rc.d/init.d/network ]; then
  mv  $BOOT_DIR/etc/rc.d/init.d/network  $BOOT_DIR/etc/rc.d/init.d/network.sav
fi
if [ -f $BOOT_DIR/etc/rc.d/init.d/atd ]; then
  mv  $BOOT_DIR/etc/rc.d/init.d/atd      $BOOT_DIR/etc/rc.d/init.d/atd.sav
fi
if [ -f $BOOT_DIR/etc/rc.d/init.d/apmd ]; then
  mv  $BOOT_DIR/etc/rc.d/init.d/apmd      $BOOT_DIR/etc/rc.d/init.d/apmd.sav
fi
if [ -f $BOOT_DIR/etc/rc.d/init.d/kudzu ]; then
  mv  $BOOT_DIR/etc/rc.d/init.d/kudzu    $BOOT_DIR/etc/rc.d/init.d/kudzu.sav
fi
if [ -f $BOOT_DIR/etc/rc.d/init.d/crond ]; then
  mv  $BOOT_DIR/etc/rc.d/init.d/crond    $BOOT_DIR/etc/rc.d/init.d/crond.sav
fi
if [ -f $BOOT_DIR/etc/rc.d/init.d/nfs ]; then
  mv  $BOOT_DIR/etc/rc.d/init.d/nfs    $BOOT_DIR/etc/rc.d/init.d/nfs.sav
fi
if [ -f $BOOT_DIR/etc/rc.d/init.d/syslog ]; then
  mv  $BOOT_DIR/etc/rc.d/init.d/syslog    $BOOT_DIR/etc/rc.d/init.d/syslog.sav
fi
if [ -f $BOOT_DIR/etc/rc.d/init.d/sendmail ]; then
  mv  $BOOT_DIR/etc/rc.d/init.d/sendmail    $BOOT_DIR/etc/rc.d/init.d/sendmail.sav
fi

# ============ Add new files  ========================
echo "Add new files - rc.sysinit.IBM_NS.sboot, XF86Config, awk scripts"
echo "                password files and other MISC files"
cp  MISC/DEV_FILES_SOURCE           $BOOT_DIR/dev/
cp  CONFIG/rc.sysinit.IBM_NS.sboot  $BOOT_DIR/etc/rc.d/rc.sysinit.IBM_NS.sboot
chmod a+x $BOOT_DIR/etc/rc.d/rc.sysinit.IBM_NS.sboot
cp  CONFIG/XF86Config.FBDev.2800    $BOOT_DIR/etc/X11/
cp  CONFIG/XF86Config.FBDev.2200    $BOOT_DIR/etc/X11/
if [ -f $BOOT_DIR/etc/X11/XF86Config.org ]; then
   echo "XF86Config.org already exists - no need to backup original"
else
  if [ -f $BOOT_DIR/etc/X11/XF86Config ]; then
    mv $BOOT_DIR/etc/X11/XF86Config  $BOOT_DIR/etc/X11/XF86Config.org
  fi
fi
if [ -f $BOOT_DIR/etc/X11/XF86Config ]; then
  rm $BOOT_DIR/etc/X11/XF86Config
fi
ln -sf /tmp/XF86Config  $BOOT_DIR/etc/X11/XF86Config
# change the real XF86Config files here - FBDev or SVGA or ?
ln -sf XF86Config.FBDev.2800 $BOOT_DIR/etc/X11/XF86Config.2800
ln -sf XF86Config.FBDev.2200 $BOOT_DIR/etc/X11/XF86Config.2200
cp  AWKS/cmdline_awk        $BOOT_DIR/bin/
cp  AWKS/gethostname_awk    $BOOT_DIR/bin/
chmod a+x $BOOT_DIR/bin/cmdline_awk
chmod a+x $BOOT_DIR/bin/gethostname_awk
echo "Add IBM Setup Utility programs"
cp -pR IBM $BOOT_DIR/
chmod a+x $BOOT_DIR/IBM/volume
mkdir -p $BOOT_DIR/root/IBM
cp MISC/passwd* $BOOT_DIR/etc/
cp MISC/*shadow* $BOOT_DIR/etc/
cp MISC/*group* $BOOT_DIR/etc/
cp MISC/i18n        $BOOT_DIR/etc/sysconfig/
cp MISC/keyboard    $BOOT_DIR/etc/sysconfig/
cp MISC/mouse       $BOOT_DIR/etc/sysconfig/


# ============ Create /tmp and /proc directories  ========================
echo "Create tmp and proc directoriess"
# Create new directories, Ram disk will be mounted on top of these directories
mkdir -p  $BOOT_DIR/tmp  
chmod a+w $BOOT_DIR/tmp  
mkdir -p  $BOOT_DIR/proc
 
# ===== Create link for var directory (created in RAM disk in /tmp)  =======
#Link var directory - var created in ram disk under /tmp
if [ -d $BOOT_DIR/var.org ]; then
  echo "Original var backup already present"
else
  echo "Backup var directory"
  mv $BOOT_DIR/var $BOOT_DIR/var.org
fi
ln -sf /tmp/var $BOOT_DIR/var


# ======== Link /etc/HOSTNAME, hosts, resolv.conf, sysconfig/network  ========
#    used for host name and name server, etc.
ln -sf /tmp/HOSTNAME $BOOT_DIR/etc/HOSTNAME
ln -sf /tmp/hosts    $BOOT_DIR/etc/hosts
#cp /etc/resolv.conf $BOOT_DIR/etc/resolv.conf
ln -sf /tmp/resolv.conf $BOOT_DIR/etc/resolv.conf
ln -sf /tmp/network $BOOT_DIR/etc/sysconfig/network

# Link mouse driver
if [ -f $BOOT_DIR/dev/mouse ]; then
  rm $BOOT_DIR/dev/mouse 
fi
ln -sf /tmp/mouse  $BOOT_DIR/dev/mouse 

# Link appropriate Xserver files
echo "Link FrameBuffer XServer"
cd $BOOT_DIR/etc/X11   
mv X X.org
ln -sf /usr/X11R6/bin/XF86_FBDev  X             
cd $current_dir
